@@ -2,6 +2,7 @@ import dataclasses
 import datetime
 import logging
 import pathlib
+import textwrap
 
 import durations
 import jinja2
@@ -21,7 +22,7 @@ now = datetime.datetime.now()
 local_now = now.astimezone()
 local_tz = local_now.tzinfo
 local_tzname = local_tz.tzname(local_now)
-net30 = datetime.timedelta(days=30)
+delta_net30 = datetime.timedelta(days=30)
 
 
 @dataclasses.dataclass
@@ -47,20 +48,34 @@ def view_hours_per_task(timesheet: model.Timesheet):
         duration = timedelta_to_short_string(delta)
         stuff.append({"duration": duration, "name": task})
 
-    template = env.get_template("view1.j2")
+    template = env.get_template("view_hours_worked_per_task.j2")
     out = template.render(data=stuff)
     return out
 
 
 def view_hours_worked_per_day(timesheet: model.Timesheet):
     stuff = []
+
     for entry in timesheet.days:
         seconds = 0
         tasks = []
         for task in entry.tasks.__root__:
             duration = durations.Duration(task.task_time)
             seconds += duration.to_seconds()
-            tasks.append(task)
+
+            minutia = task.minutia
+            minutia = " ".join(minutia.strip().split()).strip()
+            minutia = textwrap.fill(
+                minutia, initial_indent="   ", subsequent_indent="   "
+            )
+
+            modified_task = {
+                "task": task.task,
+                "minutia": minutia,
+                "task_time": task.task_time,
+            }
+
+            tasks.append(modified_task)
 
         delta = datetime.timedelta(seconds=seconds)
 
@@ -155,7 +170,7 @@ def view_hours_worked_per_day_summary(timesheet: model.Timesheet):
 
 
 def view_invoices(timesheet: model.Timesheet):
-    template = env.get_template("invoices.j2")
+    template = env.get_template("view_invoices.j2")
     invoices = timesheet.invoices.__root__
 
     display_dicts = []
@@ -165,11 +180,11 @@ def view_invoices(timesheet: model.Timesheet):
             due_date_relative = " "
             submitted_on = " "
         else:
-            due_date = invoice.submitted_on + net30
+            due_date = invoice.submitted_on + delta_net30
             delta = local_now - due_date
             due_date_relative = timeago.format(delta)
             submitted_on = invoice.submitted_on.date()
-            ts = invoice.submitted_on + net30
+            ts = invoice.submitted_on + delta_net30
             due_date_relative = f"{due_date_relative} ({ts.strftime('%m-%d')})"
 
         if invoice.paid_on:
